# pagesmith

Разбиение HTML на страницы с сохранением HTML-тегов и соблюдением исходной структуры документа и целостности текста.

Используется чрезвычайно быстрый парсер lxml.

Предоставляет утилиты для работы со страницами, такие как улучшение HTML.

Также содержит класс для разделение на страницы и извлечение оглавления из чистого текста.


!!! note "Как это работает"
    Класс `HtmlPageSplitter` интеллектуально разбивает HTML-содержимое на страницы соответствующего размера, обеспечивая при этом правильное закрытие и валидность всех HTML-тегов. Это сохраняет как структуру документа, так и его стиль.

## Установка

```bash
pip install pagesmith
```

## Использование
- [Разбиение HTML на страницы](html_splitter.md)
- [Разбиение текста на страницы](text_splitter.md)
- [Очистка HTML](refine.md)
